@@ -2,23 +2,20 @@ package WWW::MobileCarrierJP::Declare;
 use strict;
 use warnings;
 use utf8;
+use base qw/Exporter/;
 use Web::Scraper;
 use URI;
-use Sub::Exporter;
 
-my $exporter = Sub::Exporter::build_exporter(
-    {
-        exports => [qw(parse_one scraper process col as_tree)],
-        groups  => { default => [':all'] }
-    },
-);
+our @EXPORT = qw(parse_one scraper process col as_tree);
 
 sub import {
+    my $class = shift;
+
     strict->import;
     warnings->import;
     utf8->import;
 
-    goto $exporter;
+    $class->export_to_level(1);
 }
 
 sub col {
